==> haskell-chell-0.4.0.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell
version: 0.4.0.2
id: chell-0.4.0.2-5ENpvyUMfQzLCMhdmH9KuN
key: chell-0.4.0.2-5ENpvyUMfQzLCMhdmH9KuN
license: MIT
maintainer: John Millikin <john@john-millikin.com>
author: John Millikin <john@john-millikin.com>
homepage: https://john-millikin.com/software/chell/
synopsis: A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.
    .
    An example test suite, which verifies the behavior of artithmetic operators.
    .
    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;
    .
    import Test.Chell
    .
    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]
    .
    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)
    .
    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))
    .
    main :: IO ()
    main = defaultMain [tests_Math]
    @
    .
    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @
category: Testing
abi: fc2c9743a6e7c7cc923bd45ddbb1c2e0
exposed: True
exposed-modules:
    Test.Chell
hidden-modules: Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/chell-0.4.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/chell-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/chell-0.4.0.2
hs-libraries: HSchell-0.4.0.2-5ENpvyUMfQzLCMhdmH9KuN
depends:
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1 base-4.11.1.0
    bytestring-0.10.8.2 options-1.2.1.1-8yUchvvR2SaHY7Vem0H7pL
    patience-0.1.1-ByieOh635rzAIvJxHEy8CG
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV template-haskell-2.13.0.0
    text-1.2.3.0 transformers-0.5.5.0
abi-depends: ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             options-1.2.1.1-8yUchvvR2SaHY7Vem0H7pL=8f66bcbc8745db89acf1b240db0c7001
             patience-0.1.1-ByieOh635rzAIvJxHEy8CG=3fdb9ea14b83c174b7bd3d1030eba3ca
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html: /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-0.4.0.2-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell
version: 0.4.0.2
id: chell-0.4.0.2-JzCT77nUdLACEsLVzXugJ
key: chell-0.4.0.2-JzCT77nUdLACEsLVzXugJ
license: MIT
maintainer: John Millikin <john@john-millikin.com>
author: John Millikin <john@john-millikin.com>
homepage: https://john-millikin.com/software/chell/
synopsis: A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.
    .
    An example test suite, which verifies the behavior of artithmetic operators.
    .
    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;
    .
    import Test.Chell
    .
    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]
    .
    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)
    .
    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))
    .
    main :: IO ()
    main = defaultMain [tests_Math]
    @
    .
    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @
category: Testing
abi: 7ce2aa7dc15e099fa6d3f302d996947d
exposed: True
exposed-modules:
    Test.Chell
hidden-modules: Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/chell-0.4.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/chell-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/chell-0.4.0.2
hs-libraries: HSchell-0.4.0.2-JzCT77nUdLACEsLVzXugJ
depends:
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc base-4.11.1.0
    bytestring-0.10.8.2 options-1.2.1.1-8yUchvvR2SaHY7Vem0H7pL
    patience-0.1.1-ByieOh635rzAIvJxHEy8CG
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV template-haskell-2.13.0.0
    text-1.2.3.0 transformers-0.5.5.0
abi-depends: ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             options-1.2.1.1-8yUchvvR2SaHY7Vem0H7pL=8f66bcbc8745db89acf1b240db0c7001
             patience-0.1.1-ByieOh635rzAIvJxHEy8CG=3fdb9ea14b83c174b7bd3d1030eba3ca
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html: /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
